==> james-project-3.4.0-source-release.zip: james-project-3.4.0/server/container/guice/protocols/webadmin/src/main/java/org/apache/james/modules/server/NoJwtModule.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.modules.server;

import java.util.Optional;

import org.apache.james.jwt.JwtConfiguration;

import com.google.inject.AbstractModule;

public class NoJwtModule extends AbstractModule {

    @Override
    protected void configure() {
        bind(JwtConfiguration.class).toInstance(new JwtConfiguration(Optional.empty()));
    }
}

==> james-project-3.8.2-source-release.zip: james-project-3.8.2/server/container/guice/protocols/webadmin/src/main/java/org/apache/james/modules/server/NoJwtModule.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.modules.server;

import javax.inject.Named;

import org.apache.james.jwt.JwtTokenVerifier;

import com.google.inject.AbstractModule;
import com.google.inject.Provides;
import com.google.inject.Singleton;

public class NoJwtModule extends AbstractModule {
    @Provides
    @Singleton
    @Named("jmap")
    JwtTokenVerifier failWhenFallbackToJMAPConfiguration() {
        throw new RuntimeException("JMAP is not enabled thus we can not fallback to its JWT configuration");
    }
}
